Octohat
=======================

Octohat takes a github repo name, and returns a list of every github
user that has interacted with a project, but has not committed code. 

For more informaton, usage, etc; please see README.md
